==> order-center-domain-3.0.0-CLOUD-DEV-20250513.063739-176-sources.jar: com/tydic/dyc/oc/service/domainservice/UocShouldPayCreateServiceImpl.java <==
package com.tydic.dyc.oc.service.domainservice;

import cn.hutool.core.collection.ListUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.tydic.dyc.base.exception.BaseBusinessException;
import com.tydic.dyc.oc.components.es.UocEsSyncManager;
import com.tydic.dyc.oc.components.es.UocEsSyncManagerSaveDataReqBo;
import com.tydic.dyc.oc.config.UocIndexConfig;
import com.tydic.dyc.oc.constants.UocConstant;
import com.tydic.dyc.oc.constants.UocDicConstant;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.model.payorder.IUocPayOrderModel;
import com.tydic.dyc.oc.model.payorder.sub.UocOrderShouldPay;
import com.tydic.dyc.oc.model.sysdictionary.IUocSysDictionaryModel;
import com.tydic.dyc.oc.model.sysdictionary.qrybo.UocSysDictionaryQryBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocShouldPayCreateBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocShouldPayCreateReqBO;
import com.tydic.dyc.oc.service.domainservice.bo.UocShouldPayCreateRspBO;
import com.tydic.dyc.oc.utils.IdUtil;
import com.tydic.dyc.oc.utils.UocRu;
import lombok.extern.ohaotian.HTServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 标题：UocShouldPayCreateServiceImpl
 * 说明：订单应付单创建
 * 时间：2022/4/8 14:56
 * 作者： 周中贤
 */
@Slf4j
@HTServiceImpl
public class UocShouldPayCreateServiceImpl implements UocShouldPayCreateService {

    @Autowired
    private IUocPayOrderModel iUocPayOrderModel;
    @Autowired
    private UocIndexConfig uocIndexConfig;
    @Autowired
    private UocEsSyncManager uocEsSyncManager;
    @Autowired
    private IUocSysDictionaryModel iUocSysDictionaryModel;

    protected static final List<String> pCodeList = ListUtil.list(false);

    static {
        initialize();
    }

    /**
     * 初始化pCode集合
     */
    private static void initialize() {
        //应付类型
        pCodeList.add(UocDicConstant.SHOULD_PAY_TYPE.P_CODE);
    }

    /**
     * 订单应付单创建
     */
    @Override
    public UocShouldPayCreateRspBO create(UocShouldPayCreateReqBO reqBO) {
        if (reqBO == null || CollectionUtils.isEmpty(reqBO.getUocShouldPayCreateBoList())) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        //获取字典集合
        UocSysDictionaryQryBo dictQryBo = new UocSysDictionaryQryBo();
        dictQryBo.setPCodes(pCodeList);
        dictQryBo.setSysTenantId(reqBO.getSysTenantId());
        Map<String, Map<String, String>> dictionaryMap = iUocSysDictionaryModel.getDictionaryMap(dictQryBo);
        //应付单入库
        for (UocShouldPayCreateBo item : reqBO.getUocShouldPayCreateBoList()) {
            UocOrderShouldPay uocOrderShouldPay = UocRu.js(item, UocOrderShouldPay.class);
            //生成订单应付单id
            uocOrderShouldPay.setShouldPayId(IdUtil.nextId());
            //创建时间
            uocOrderShouldPay.setCreateTime(new Date());
            //未支付状态
            uocOrderShouldPay.setIsPayCompleted(UocDicConstant.SHOULD_PAY_ORDER_PAY_STATE.NOT_PAY_COMPLETED);
            iUocPayOrderModel.createShouldPayOrder(uocOrderShouldPay);
        }
        //同步ES
        for (UocShouldPayCreateBo item : reqBO.getUocShouldPayCreateBoList()) {
            if (UocDicConstant.OBJ_TYPE.SALE.equals(reqBO.getObjectType())) {
                //单据类型为’销售单‘时，同步销售单ES
                //1、查询未支付状态的应付单
                UocOrderShouldPay uocOrderShouldPay = new UocOrderShouldPay();
                uocOrderShouldPay.setOrderId(item.getOrderId());
                uocOrderShouldPay.setObjectId(item.getObjectId());
                uocOrderShouldPay.setObjectType(UocDicConstant.OBJ_TYPE.SALE);
                uocOrderShouldPay.setIsPayCompleted(UocDicConstant.SHOULD_PAY_ORDER_PAY_STATE.NOT_PAY_COMPLETED);
                log.info("查询未支付状态的应付单入参为:{}",JSONObject.toJSONString(uocOrderShouldPay));
                List<UocOrderShouldPay> listOrderShouldPay = iUocPayOrderModel.getListOrderShouldPay(uocOrderShouldPay);
                log.info("查询未支付状态的应付单结果为：{}",JSONObject.toJSONString(listOrderShouldPay));
                if (!CollectionUtils.isEmpty(listOrderShouldPay)) {
                    JSONArray jsonArray = new JSONArray();
                    for (UocOrderShouldPay shouldPayItem : listOrderShouldPay) {
                        JSONObject jsonObject = new JSONObject();
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.FSC_SHOULD_PAY_ID, shouldPayItem.getFscShouldPayId());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.SHOULD_PAY_AMOUNT, shouldPayItem.getShouldPayAmount());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.PAID_AMOUNT, shouldPayItem.getPaidAmount());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.SHOULD_PAY_TYPE, shouldPayItem.getShouldPayType());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.PAYER_ID, shouldPayItem.getPayerId());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.PAYEE_ID, shouldPayItem.getPayeeId());
                        if (null != shouldPayItem.getShouldPayType()) {
                            jsonObject.put(UocConstant.ES_MAIN_OTHER.SHOULD_PAY_TYPE_STR, dictionaryMap.get(UocDicConstant.SHOULD_PAY_TYPE.P_CODE).get(String.valueOf(shouldPayItem.getShouldPayType())));
                        }
                        jsonArray.add(jsonObject);
                    }
                    //同步销售单ES
                    log.info("同步的jsonArray为：{}",jsonArray);
                    syncEs(item.getObjectId(), jsonArray);
                }
            }
        }

        return UocRu.success(UocShouldPayCreateRspBO.class);
    }

    /**
     * 同步ES
     */
    private void syncEs(Long objId, JSONArray jsonArray) {
        UocEsSyncManagerSaveDataReqBo uocEsSyncManagerSaveDataReqBo = new UocEsSyncManagerSaveDataReqBo();
        //objId
        uocEsSyncManagerSaveDataReqBo.setObjId(objId);
        //indexName
        uocEsSyncManagerSaveDataReqBo.setIndexName(uocIndexConfig.getSaleOrderIndex());
        JSONObject jsonObj = new JSONObject();
        //未支付状态应付订单列表
        jsonObj.put(UocConstant.ES_MAIN_OTHER.ORDER_SHOULD_PAY_LIST, jsonArray);
        //jsonObj
        uocEsSyncManagerSaveDataReqBo.setJsonObj(jsonObj);
        log.info("应付单生成uocEsSyncManagerSaveDataReqBo为{}", JSONObject.toJSONString(uocEsSyncManagerSaveDataReqBo));
        uocEsSyncManager.updateData(uocEsSyncManagerSaveDataReqBo);
    }

}

==> order-center-domain-3.1.0-CLOUD-DEV-20230213.023546-22-sources.jar: com/tydic/dyc/oc/service/domainservice/UocShouldPayCreateServiceImpl.java <==
package com.tydic.dyc.oc.service.domainservice;

import cn.hutool.core.collection.ListUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.tydic.dyc.base.exception.BaseBusinessException;
import com.tydic.dyc.oc.components.es.UocEsSyncManager;
import com.tydic.dyc.oc.components.es.UocEsSyncManagerSaveDataReqBo;
import com.tydic.dyc.oc.config.UocIndexConfig;
import com.tydic.dyc.oc.constants.UocConstant;
import com.tydic.dyc.oc.constants.UocDicConstant;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.model.payorder.IUocPayOrderModel;
import com.tydic.dyc.oc.model.payorder.sub.UocOrderShouldPay;
import com.tydic.dyc.oc.model.sysdictionary.IUocSysDictionaryModel;
import com.tydic.dyc.oc.service.domainservice.bo.UocShouldPayCreateBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocShouldPayCreateReqBO;
import com.tydic.dyc.oc.service.domainservice.bo.UocShouldPayCreateRspBO;
import com.tydic.dyc.oc.utils.IdUtil;
import com.tydic.dyc.oc.utils.UocRu;
import lombok.extern.ohaotian.HTServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 标题：UocShouldPayCreateServiceImpl
 * 说明：订单应付单创建
 * 时间：2022/4/8 14:56
 * 作者： 周中贤
 */
@Slf4j
@HTServiceImpl
public class UocShouldPayCreateServiceImpl implements UocShouldPayCreateService {

    @Autowired
    private IUocPayOrderModel iUocPayOrderModel;
    @Autowired
    private UocIndexConfig uocIndexConfig;
    @Autowired
    private UocEsSyncManager uocEsSyncManager;
    @Autowired
    private IUocSysDictionaryModel iUocSysDictionaryModel;

    protected static final List<String> pCodeList = ListUtil.list(false);

    static {
        initialize();
    }

    /**
     * 初始化pCode集合
     */
    private static void initialize() {
        //应付类型
        pCodeList.add(UocDicConstant.SHOULD_PAY_TYPE.P_CODE);
    }

    /**
     * 订单应付单创建
     */
    @Override
    public UocShouldPayCreateRspBO create(UocShouldPayCreateReqBO reqBO) {
        if (reqBO == null || CollectionUtils.isEmpty(reqBO.getUocShouldPayCreateBoList())) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参对象不能为空");
        }
        //获取字典集合
        Map<String, Map<String, String>> dictionaryMap = iUocSysDictionaryModel.getDictionaryMap(pCodeList);
        //应付单入库
        for (UocShouldPayCreateBo item : reqBO.getUocShouldPayCreateBoList()) {
            UocOrderShouldPay uocOrderShouldPay = UocRu.js(item, UocOrderShouldPay.class);
            //生成订单应付单id
            uocOrderShouldPay.setShouldPayId(IdUtil.nextId());
            //创建时间
            uocOrderShouldPay.setCreateTime(new Date());
            //未支付状态
            uocOrderShouldPay.setIsPayCompleted(UocDicConstant.SHOULD_PAY_ORDER_PAY_STATE.NOT_PAY_COMPLETED);
            iUocPayOrderModel.createShouldPayOrder(uocOrderShouldPay);
        }
        //同步ES
        for (UocShouldPayCreateBo item : reqBO.getUocShouldPayCreateBoList()) {
            if (UocDicConstant.OBJ_TYPE.SALE.equals(reqBO.getObjectType())) {
                //单据类型为’销售单‘时，同步销售单ES
                //1、查询未支付状态的应付单
                UocOrderShouldPay uocOrderShouldPay = new UocOrderShouldPay();
                uocOrderShouldPay.setOrderId(item.getOrderId());
                uocOrderShouldPay.setObjectId(item.getObjectId());
                uocOrderShouldPay.setObjectType(UocDicConstant.OBJ_TYPE.SALE);
                uocOrderShouldPay.setIsPayCompleted(UocDicConstant.SHOULD_PAY_ORDER_PAY_STATE.NOT_PAY_COMPLETED);
                log.info("查询未支付状态的应付单入参为:{}",JSONObject.toJSONString(uocOrderShouldPay));
                List<UocOrderShouldPay> listOrderShouldPay = iUocPayOrderModel.getListOrderShouldPay(uocOrderShouldPay);
                log.info("查询未支付状态的应付单结果为：{}",JSONObject.toJSONString(listOrderShouldPay));
                if (!CollectionUtils.isEmpty(listOrderShouldPay)) {
                    JSONArray jsonArray = new JSONArray();
                    for (UocOrderShouldPay shouldPayItem : listOrderShouldPay) {
                        JSONObject jsonObject = new JSONObject();
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.FSC_SHOULD_PAY_ID, shouldPayItem.getFscShouldPayId());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.SHOULD_PAY_AMOUNT, shouldPayItem.getShouldPayAmount());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.PAID_AMOUNT, shouldPayItem.getPaidAmount());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.SHOULD_PAY_TYPE, shouldPayItem.getShouldPayType());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.PAYER_ID, shouldPayItem.getPayerId());
                        jsonObject.put(UocConstant.ES_MAIN_OTHER.PAYEE_ID, shouldPayItem.getPayeeId());
                        if (null != shouldPayItem.getShouldPayType()) {
                            jsonObject.put(UocConstant.ES_MAIN_OTHER.SHOULD_PAY_TYPE_STR, dictionaryMap.get(UocDicConstant.SHOULD_PAY_TYPE.P_CODE).get(String.valueOf(shouldPayItem.getShouldPayType())));
                        }
                        jsonArray.add(jsonObject);
                    }
                    //同步销售单ES
                    log.info("同步的jsonArray为：{}",jsonArray);
                    syncEs(item.getObjectId(), jsonArray);
                }
            }
        }

        return UocRu.success(UocShouldPayCreateRspBO.class);
    }

    /**
     * 同步ES
     */
    private void syncEs(Long objId, JSONArray jsonArray) {
        UocEsSyncManagerSaveDataReqBo uocEsSyncManagerSaveDataReqBo = new UocEsSyncManagerSaveDataReqBo();
        //objId
        uocEsSyncManagerSaveDataReqBo.setObjId(objId);
        //indexName
        uocEsSyncManagerSaveDataReqBo.setIndexName(uocIndexConfig.getSaleOrderIndex());
        JSONObject jsonObj = new JSONObject();
        //未支付状态应付订单列表
        jsonObj.put(UocConstant.ES_MAIN_OTHER.ORDER_SHOULD_PAY_LIST, jsonArray);
        //jsonObj
        uocEsSyncManagerSaveDataReqBo.setJsonObj(jsonObj);
        log.info("应付单生成uocEsSyncManagerSaveDataReqBo为{}", JSONObject.toJSONString(uocEsSyncManagerSaveDataReqBo));
        uocEsSyncManager.updateData(uocEsSyncManagerSaveDataReqBo);
    }

}
